<a id="mypy-boto3-connect"></a>

# mypy-boto3-connect

[![PyPI - mypy-boto3-connect](https://img.shields.io/pypi/v/mypy-boto3-connect.svg?color=blue)](https://pypi.org/project/mypy-boto3-connect)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-connect.svg?color=blue)](https://pypi.org/project/mypy-boto3-connect)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-connect?color=blue)](https://pypistats.org/packages/mypy-boto3-connect)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Connect 1.18.29](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/connect.html#Connect)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.1.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-connect docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_connect/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-connect](#mypy-boto3-connect)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `Connect` service.

```bash
python -m pip install boto3-stubs[connect]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[connect]` in your environment:
  `python -m pip install 'boto3-stubs[connect]'`

Both type checking and auto-complete should work for `Connect` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[connect]` in your environment:
  `python -m pip install 'boto3-stubs[connect]'`

Both type checking and auto-complete should work for `Connect` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[connect]` in your environment:
  `python -m pip install 'boto3-stubs[connect]'`
- Run `mypy` as usual

Type checking should work for `Connect` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[connect]` in your environment:
  `python -m pip install 'boto3-stubs[connect]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Connect` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ConnectClient` provides annotations for `boto3.client("connect")`.

```python
import boto3

from mypy_boto3_connect import ConnectClient

client: ConnectClient = boto3.client("connect")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ConnectClient = session.client("connect")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_connect.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_connect import ConnectClient
from mypy_boto3_connect.paginator import (
    GetMetricDataPaginator,
    ListAgentStatusesPaginator,
    ListApprovedOriginsPaginator,
    ListBotsPaginator,
    ListContactFlowsPaginator,
    ListHoursOfOperationsPaginator,
    ListInstanceAttributesPaginator,
    ListInstanceStorageConfigsPaginator,
    ListInstancesPaginator,
    ListIntegrationAssociationsPaginator,
    ListLambdaFunctionsPaginator,
    ListLexBotsPaginator,
    ListPhoneNumbersPaginator,
    ListPromptsPaginator,
    ListQueueQuickConnectsPaginator,
    ListQueuesPaginator,
    ListQuickConnectsPaginator,
    ListRoutingProfileQueuesPaginator,
    ListRoutingProfilesPaginator,
    ListSecurityKeysPaginator,
    ListSecurityProfilesPaginator,
    ListUseCasesPaginator,
    ListUserHierarchyGroupsPaginator,
    ListUsersPaginator,
)

client: ConnectClient = boto3.client("connect")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
get_metric_data_paginator: GetMetricDataPaginator = client.get_paginator("get_metric_data")
list_agent_statuses_paginator: ListAgentStatusesPaginator = client.get_paginator("list_agent_statuses")
list_approved_origins_paginator: ListApprovedOriginsPaginator = client.get_paginator("list_approved_origins")
list_bots_paginator: ListBotsPaginator = client.get_paginator("list_bots")
list_contact_flows_paginator: ListContactFlowsPaginator = client.get_paginator("list_contact_flows")
list_hours_of_operations_paginator: ListHoursOfOperationsPaginator = client.get_paginator("list_hours_of_operations")
list_instance_attributes_paginator: ListInstanceAttributesPaginator = client.get_paginator("list_instance_attributes")
list_instance_storage_configs_paginator: ListInstanceStorageConfigsPaginator = client.get_paginator("list_instance_storage_configs")
list_instances_paginator: ListInstancesPaginator = client.get_paginator("list_instances")
list_integration_associations_paginator: ListIntegrationAssociationsPaginator = client.get_paginator("list_integration_associations")
list_lambda_functions_paginator: ListLambdaFunctionsPaginator = client.get_paginator("list_lambda_functions")
list_lex_bots_paginator: ListLexBotsPaginator = client.get_paginator("list_lex_bots")
list_phone_numbers_paginator: ListPhoneNumbersPaginator = client.get_paginator("list_phone_numbers")
list_prompts_paginator: ListPromptsPaginator = client.get_paginator("list_prompts")
list_queue_quick_connects_paginator: ListQueueQuickConnectsPaginator = client.get_paginator("list_queue_quick_connects")
list_queues_paginator: ListQueuesPaginator = client.get_paginator("list_queues")
list_quick_connects_paginator: ListQuickConnectsPaginator = client.get_paginator("list_quick_connects")
list_routing_profile_queues_paginator: ListRoutingProfileQueuesPaginator = client.get_paginator("list_routing_profile_queues")
list_routing_profiles_paginator: ListRoutingProfilesPaginator = client.get_paginator("list_routing_profiles")
list_security_keys_paginator: ListSecurityKeysPaginator = client.get_paginator("list_security_keys")
list_security_profiles_paginator: ListSecurityProfilesPaginator = client.get_paginator("list_security_profiles")
list_use_cases_paginator: ListUseCasesPaginator = client.get_paginator("list_use_cases")
list_user_hierarchy_groups_paginator: ListUserHierarchyGroupsPaginator = client.get_paginator("list_user_hierarchy_groups")
list_users_paginator: ListUsersPaginator = client.get_paginator("list_users")
```

<a id="literals"></a>

### Literals

`mypy_boto3_connect.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_connect.literals import (
    AgentStatusStateType,
    AgentStatusTypeType,
    ChannelType,
    ComparisonType,
    ContactFlowTypeType,
    CurrentMetricNameType,
    DirectoryTypeType,
    EncryptionTypeType,
    GetMetricDataPaginatorName,
    GroupingType,
    HistoricalMetricNameType,
    HoursOfOperationDaysType,
    InstanceAttributeTypeType,
    InstanceStatusType,
    InstanceStorageResourceTypeType,
    IntegrationTypeType,
    LexVersionType,
    ListAgentStatusesPaginatorName,
    ListApprovedOriginsPaginatorName,
    ListBotsPaginatorName,
    ListContactFlowsPaginatorName,
    ListHoursOfOperationsPaginatorName,
    ListInstanceAttributesPaginatorName,
    ListInstanceStorageConfigsPaginatorName,
    ListInstancesPaginatorName,
    ListIntegrationAssociationsPaginatorName,
    ListLambdaFunctionsPaginatorName,
    ListLexBotsPaginatorName,
    ListPhoneNumbersPaginatorName,
    ListPromptsPaginatorName,
    ListQueueQuickConnectsPaginatorName,
    ListQueuesPaginatorName,
    ListQuickConnectsPaginatorName,
    ListRoutingProfileQueuesPaginatorName,
    ListRoutingProfilesPaginatorName,
    ListSecurityKeysPaginatorName,
    ListSecurityProfilesPaginatorName,
    ListUseCasesPaginatorName,
    ListUserHierarchyGroupsPaginatorName,
    ListUsersPaginatorName,
    PhoneNumberCountryCodeType,
    PhoneNumberTypeType,
    PhoneTypeType,
    QueueStatusType,
    QueueTypeType,
    QuickConnectTypeType,
    ReferenceTypeType,
    SourceTypeType,
    StatisticType,
    StorageTypeType,
    UnitType,
    UseCaseTypeType,
    VoiceRecordingTrackType,
)

def check_value(value: AgentStatusStateType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_connect.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_connect.type_defs import (
    AgentStatusSummaryTypeDef,
    AgentStatusTypeDef,
    AssociateApprovedOriginRequestRequestTypeDef,
    AssociateBotRequestRequestTypeDef,
    AssociateInstanceStorageConfigRequestRequestTypeDef,
    AssociateInstanceStorageConfigResponseTypeDef,
    AssociateLambdaFunctionRequestRequestTypeDef,
    AssociateLexBotRequestRequestTypeDef,
    AssociateQueueQuickConnectsRequestRequestTypeDef,
    AssociateRoutingProfileQueuesRequestRequestTypeDef,
    AssociateSecurityKeyRequestRequestTypeDef,
    AssociateSecurityKeyResponseTypeDef,
    AttributeTypeDef,
    ChatMessageTypeDef,
    ContactFlowSummaryTypeDef,
    ContactFlowTypeDef,
    CreateAgentStatusRequestRequestTypeDef,
    CreateAgentStatusResponseTypeDef,
    CreateContactFlowRequestRequestTypeDef,
    CreateContactFlowResponseTypeDef,
    CreateHoursOfOperationRequestRequestTypeDef,
    CreateHoursOfOperationResponseTypeDef,
    CreateInstanceRequestRequestTypeDef,
    CreateInstanceResponseTypeDef,
    CreateIntegrationAssociationRequestRequestTypeDef,
    CreateIntegrationAssociationResponseTypeDef,
    CreateQueueRequestRequestTypeDef,
    CreateQueueResponseTypeDef,
    CreateQuickConnectRequestRequestTypeDef,
    CreateQuickConnectResponseTypeDef,
    CreateRoutingProfileRequestRequestTypeDef,
    CreateRoutingProfileResponseTypeDef,
    CreateUseCaseRequestRequestTypeDef,
    CreateUseCaseResponseTypeDef,
    CreateUserHierarchyGroupRequestRequestTypeDef,
    CreateUserHierarchyGroupResponseTypeDef,
    CreateUserRequestRequestTypeDef,
    CreateUserResponseTypeDef,
    CredentialsTypeDef,
    CurrentMetricDataTypeDef,
    CurrentMetricResultTypeDef,
    CurrentMetricTypeDef,
    DeleteHoursOfOperationRequestRequestTypeDef,
    DeleteInstanceRequestRequestTypeDef,
    DeleteIntegrationAssociationRequestRequestTypeDef,
    DeleteQuickConnectRequestRequestTypeDef,
    DeleteUseCaseRequestRequestTypeDef,
    DeleteUserHierarchyGroupRequestRequestTypeDef,
    DeleteUserRequestRequestTypeDef,
    DescribeAgentStatusRequestRequestTypeDef,
    DescribeAgentStatusResponseTypeDef,
    DescribeContactFlowRequestRequestTypeDef,
    DescribeContactFlowResponseTypeDef,
    DescribeHoursOfOperationRequestRequestTypeDef,
    DescribeHoursOfOperationResponseTypeDef,
    DescribeInstanceAttributeRequestRequestTypeDef,
    DescribeInstanceAttributeResponseTypeDef,
    DescribeInstanceRequestRequestTypeDef,
    DescribeInstanceResponseTypeDef,
    DescribeInstanceStorageConfigRequestRequestTypeDef,
    DescribeInstanceStorageConfigResponseTypeDef,
    DescribeQueueRequestRequestTypeDef,
    DescribeQueueResponseTypeDef,
    DescribeQuickConnectRequestRequestTypeDef,
    DescribeQuickConnectResponseTypeDef,
    DescribeRoutingProfileRequestRequestTypeDef,
    DescribeRoutingProfileResponseTypeDef,
    DescribeUserHierarchyGroupRequestRequestTypeDef,
    DescribeUserHierarchyGroupResponseTypeDef,
    DescribeUserHierarchyStructureRequestRequestTypeDef,
    DescribeUserHierarchyStructureResponseTypeDef,
    DescribeUserRequestRequestTypeDef,
    DescribeUserResponseTypeDef,
    DimensionsTypeDef,
    DisassociateApprovedOriginRequestRequestTypeDef,
    DisassociateBotRequestRequestTypeDef,
    DisassociateInstanceStorageConfigRequestRequestTypeDef,
    DisassociateLambdaFunctionRequestRequestTypeDef,
    DisassociateLexBotRequestRequestTypeDef,
    DisassociateQueueQuickConnectsRequestRequestTypeDef,
    DisassociateRoutingProfileQueuesRequestRequestTypeDef,
    DisassociateSecurityKeyRequestRequestTypeDef,
    EncryptionConfigTypeDef,
    FiltersTypeDef,
    GetContactAttributesRequestRequestTypeDef,
    GetContactAttributesResponseTypeDef,
    GetCurrentMetricDataRequestRequestTypeDef,
    GetCurrentMetricDataResponseTypeDef,
    GetFederationTokenRequestRequestTypeDef,
    GetFederationTokenResponseTypeDef,
    GetMetricDataRequestRequestTypeDef,
    GetMetricDataResponseTypeDef,
    HierarchyGroupSummaryTypeDef,
    HierarchyGroupTypeDef,
    HierarchyLevelTypeDef,
    HierarchyLevelUpdateTypeDef,
    HierarchyPathTypeDef,
    HierarchyStructureTypeDef,
    HierarchyStructureUpdateTypeDef,
    HistoricalMetricDataTypeDef,
    HistoricalMetricResultTypeDef,
    HistoricalMetricTypeDef,
    HoursOfOperationConfigTypeDef,
    HoursOfOperationSummaryTypeDef,
    HoursOfOperationTimeSliceTypeDef,
    HoursOfOperationTypeDef,
    InstanceStatusReasonTypeDef,
    InstanceStorageConfigTypeDef,
    InstanceSummaryTypeDef,
    InstanceTypeDef,
    IntegrationAssociationSummaryTypeDef,
    KinesisFirehoseConfigTypeDef,
    KinesisStreamConfigTypeDef,
    KinesisVideoStreamConfigTypeDef,
    LexBotConfigTypeDef,
    LexBotTypeDef,
    LexV2BotTypeDef,
    ListAgentStatusRequestRequestTypeDef,
    ListAgentStatusResponseTypeDef,
    ListApprovedOriginsRequestRequestTypeDef,
    ListApprovedOriginsResponseTypeDef,
    ListBotsRequestRequestTypeDef,
    ListBotsResponseTypeDef,
    ListContactFlowsRequestRequestTypeDef,
    ListContactFlowsResponseTypeDef,
    ListHoursOfOperationsRequestRequestTypeDef,
    ListHoursOfOperationsResponseTypeDef,
    ListInstanceAttributesRequestRequestTypeDef,
    ListInstanceAttributesResponseTypeDef,
    ListInstanceStorageConfigsRequestRequestTypeDef,
    ListInstanceStorageConfigsResponseTypeDef,
    ListInstancesRequestRequestTypeDef,
    ListInstancesResponseTypeDef,
    ListIntegrationAssociationsRequestRequestTypeDef,
    ListIntegrationAssociationsResponseTypeDef,
    ListLambdaFunctionsRequestRequestTypeDef,
    ListLambdaFunctionsResponseTypeDef,
    ListLexBotsRequestRequestTypeDef,
    ListLexBotsResponseTypeDef,
    ListPhoneNumbersRequestRequestTypeDef,
    ListPhoneNumbersResponseTypeDef,
    ListPromptsRequestRequestTypeDef,
    ListPromptsResponseTypeDef,
    ListQueueQuickConnectsRequestRequestTypeDef,
    ListQueueQuickConnectsResponseTypeDef,
    ListQueuesRequestRequestTypeDef,
    ListQueuesResponseTypeDef,
    ListQuickConnectsRequestRequestTypeDef,
    ListQuickConnectsResponseTypeDef,
    ListRoutingProfileQueuesRequestRequestTypeDef,
    ListRoutingProfileQueuesResponseTypeDef,
    ListRoutingProfilesRequestRequestTypeDef,
    ListRoutingProfilesResponseTypeDef,
    ListSecurityKeysRequestRequestTypeDef,
    ListSecurityKeysResponseTypeDef,
    ListSecurityProfilesRequestRequestTypeDef,
    ListSecurityProfilesResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListUseCasesRequestRequestTypeDef,
    ListUseCasesResponseTypeDef,
    ListUserHierarchyGroupsRequestRequestTypeDef,
    ListUserHierarchyGroupsResponseTypeDef,
    ListUsersRequestRequestTypeDef,
    ListUsersResponseTypeDef,
    MediaConcurrencyTypeDef,
    OutboundCallerConfigTypeDef,
    PaginatorConfigTypeDef,
    ParticipantDetailsTypeDef,
    PhoneNumberQuickConnectConfigTypeDef,
    PhoneNumberSummaryTypeDef,
    PromptSummaryTypeDef,
    QueueQuickConnectConfigTypeDef,
    QueueReferenceTypeDef,
    QueueSummaryTypeDef,
    QueueTypeDef,
    QuickConnectConfigTypeDef,
    QuickConnectSummaryTypeDef,
    QuickConnectTypeDef,
    ReferenceTypeDef,
    ResponseMetadataTypeDef,
    ResumeContactRecordingRequestRequestTypeDef,
    RoutingProfileQueueConfigSummaryTypeDef,
    RoutingProfileQueueConfigTypeDef,
    RoutingProfileQueueReferenceTypeDef,
    RoutingProfileSummaryTypeDef,
    RoutingProfileTypeDef,
    S3ConfigTypeDef,
    SecurityKeyTypeDef,
    SecurityProfileSummaryTypeDef,
    StartChatContactRequestRequestTypeDef,
    StartChatContactResponseTypeDef,
    StartContactRecordingRequestRequestTypeDef,
    StartOutboundVoiceContactRequestRequestTypeDef,
    StartOutboundVoiceContactResponseTypeDef,
    StartTaskContactRequestRequestTypeDef,
    StartTaskContactResponseTypeDef,
    StopContactRecordingRequestRequestTypeDef,
    StopContactRequestRequestTypeDef,
    SuspendContactRecordingRequestRequestTypeDef,
    TagResourceRequestRequestTypeDef,
    ThresholdTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateAgentStatusRequestRequestTypeDef,
    UpdateContactAttributesRequestRequestTypeDef,
    UpdateContactFlowContentRequestRequestTypeDef,
    UpdateContactFlowNameRequestRequestTypeDef,
    UpdateHoursOfOperationRequestRequestTypeDef,
    UpdateInstanceAttributeRequestRequestTypeDef,
    UpdateInstanceStorageConfigRequestRequestTypeDef,
    UpdateQueueHoursOfOperationRequestRequestTypeDef,
    UpdateQueueMaxContactsRequestRequestTypeDef,
    UpdateQueueNameRequestRequestTypeDef,
    UpdateQueueOutboundCallerConfigRequestRequestTypeDef,
    UpdateQueueStatusRequestRequestTypeDef,
    UpdateQuickConnectConfigRequestRequestTypeDef,
    UpdateQuickConnectNameRequestRequestTypeDef,
    UpdateRoutingProfileConcurrencyRequestRequestTypeDef,
    UpdateRoutingProfileDefaultOutboundQueueRequestRequestTypeDef,
    UpdateRoutingProfileNameRequestRequestTypeDef,
    UpdateRoutingProfileQueuesRequestRequestTypeDef,
    UpdateUserHierarchyGroupNameRequestRequestTypeDef,
    UpdateUserHierarchyRequestRequestTypeDef,
    UpdateUserHierarchyStructureRequestRequestTypeDef,
    UpdateUserIdentityInfoRequestRequestTypeDef,
    UpdateUserPhoneConfigRequestRequestTypeDef,
    UpdateUserRoutingProfileRequestRequestTypeDef,
    UpdateUserSecurityProfilesRequestRequestTypeDef,
    UseCaseTypeDef,
    UserIdentityInfoTypeDef,
    UserPhoneConfigTypeDef,
    UserQuickConnectConfigTypeDef,
    UserSummaryTypeDef,
    UserTypeDef,
    VoiceRecordingConfigurationTypeDef,
)

def get_structure() -> AgentStatusSummaryTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-connect` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-connect docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_connect/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
